Package: FSelectorRcpp
Type: Package
Title: 'Rcpp' Implementation of 'FSelector' Entropy-Based Feature
        Selection Algorithms with a Sparse Matrix Support
Version: 0.3.13
Authors@R: c(
 person("Zygmunt", "Zawadzki", role = c("aut", "cre"), email = "zygmunt@zstat.pl"),
 person("Marcin", "Kosinski", role = c("aut"), email = "m.p.kosinski@gmail.com"),
 person("Krzysztof", "Slomczynski", role = c("ctb"), email = "krzysztofslomczynski@gmail.com"),
 person("Damian", "Skrzypiec", role = c("ctb"), email = "damian.j.skrzypiec@gmail.com"),
 person(given = "Patrick", family = "Schratz", role = c("ctb"), email = "patrick.schratz@gmail.com", comment = c(ORCID = "0000-0003-0748-6624"))
 )
Description: 'Rcpp' (free of 'Java'/'Weka') implementation of 'FSelector' entropy-based feature selection 
 algorithms based on an MDL discretization (Fayyad U. M., Irani K. B.: Multi-Interval Discretization of Continuous-Valued Attributes for Classification Learning.
 In 13'th International Joint Conference on Uncertainly in Artificial Intelligence (IJCAI93), pages 1022-1029, Chambery, France, 1993.) <https://www.ijcai.org/Proceedings/93-2/Papers/022.pdf>
 with a sparse matrix support.
Depends: R (>= 3.4)
License: GPL-2
Imports: Rcpp (>= 0.12.12), foreach, iterators
LinkingTo: Rcpp, BH, RcppArmadillo, testthat
Suggests: Matrix, testthat, RcppArmadillo, dplyr, RWeka, entropy,
        FSelector, randomForest, doParallel, rpart, MASS, covr,
        parallel, htmltools, magrittr, knitr, RTCGA.rnaseq, ggplot2,
        microbenchmark, pbapply, tibble, rmarkdown, lintr, pkgdown,
        withr
RoxygenNote: 7.3.2
Encoding: UTF-8
BugReports: https://github.com/mi2-warsaw/FSelectorRcpp/issues
URL: https://github.com/mi2-warsaw/FSelectorRcpp
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2024-10-01 10:18:27 UTC; zzawadz
Author: Zygmunt Zawadzki [aut, cre],
  Marcin Kosinski [aut],
  Krzysztof Slomczynski [ctb],
  Damian Skrzypiec [ctb],
  Patrick Schratz [ctb] (<https://orcid.org/0000-0003-0748-6624>)
Maintainer: Zygmunt Zawadzki <zygmunt@zstat.pl>
Repository: CRAN
Date/Publication: 2024-10-02 22:40:26 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-28 17:43:07 UTC; unix
Archs: FSelectorRcpp.so.dSYM
