# Generated by roxygen2: do not edit by hand

S3method(.information_gain,data.frame)
S3method(.information_gain,default)
S3method(.information_gain,dgCMatrix)
S3method(.information_gain,formula)
S3method(discretize,data.frame)
S3method(discretize,default)
S3method(discretize,formula)
S3method(discretize,list)
S3method(discretize,matrix)
S3method(discretize,numeric)
S3method(discretize_transform,FsDiscretizeTransformer)
S3method(discretize_transform,data.frame)
S3method(print,FsDiscretizeTransformer)
export(.information_gain)
export(customBreaksControl)
export(cut_attrs)
export(discretize)
export(discretize_transform)
export(equalsizeControl)
export(extract_discretize_transformer)
export(feature_search)
export(information_gain)
export(mdlControl)
export(relief)
export(to_formula)
importFrom(Rcpp,evalCpp)
importFrom(foreach,"%do%")
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(foreach,getDoParName)
importFrom(foreach,getDoParRegistered)
importFrom(iterators,iter)
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,formula)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(utils,combn)
importFrom(utils,tail)
useDynLib(FSelectorRcpp, .registration = TRUE)
